@@ -2,9 +2,7 @@ package HTML::TokeParser::Simple::Token::Declaration;
 
 use strict;
 
-use vars qw/ $VERSION $REVISION /;
-$REVISION = '$Id: Declaration.pm,v 1.2 2004/09/25 23:36:53 ovid Exp $';
-$VERSION  = '1.0';
+our $VERSION  = '3.15';
 use base 'HTML::TokeParser::Simple::Token';
 
 sub is_declaration { 1 }
@@ -30,5 +28,13 @@ HTML::TokeParser::Simple::Token::Declaration - Token.pm declaration class.
 
 =head1 DESCRIPTION
 
-This is the declaration class for tokens.  C<is_declaration()> will return true
-if the token is the DTD at the top of the HTML.
+This is the declaration class for tokens. 
+
+=head1 OVERRIDDEN METHODS
+
+=head2 is_declaration
+
+C<is_declaration()> will return true if the token is the DTD at the top of the
+HTML.
+
+=cut
